# BillingDetails

Billing details to use associated to a buyer.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**first_name** | **str, none_type** | The first name(s) or given name for the buyer. | [optional] 
**last_name** | **str, none_type** | The last name, or family name, of the buyer. | [optional] 
**email_address** | **str, none_type** | The email address for the buyer. | [optional] 
**phone_number** | **str, none_type** | The phone number to use for this request. This expect the number in the [E164 number standard](https://www.twilio.com/docs/glossary/what-e164). | [optional] 
**address** | **object** |  | [optional] 
**tax_id** | **object** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


